* ============================================================== *
* Equality of Opportunity for Sexual and Gender Minorities 2024
* Code written by Omar Alburqueque, and reviewed by Paola Ballon
* Contact: oalburquequechav@worldbank.org
* <Outcomes>
* ============================================================== *

* ----------- *
* Indications *
* ----------- *

* 1. This script allows the user to reproduce the following inputs used in the EQOSOGI report 2024
*	- Tables: 1.2, 1.3, 3.1
*	- Figures: 1.1, 1.2, 1.3, 1.4, 1.5
*	- Online appendix:
* 		-> EQOSOGI dataset
* 		-> Descriptive statistics for all binary responses
* 		-> Overall and indicator-set scores summary statistics, by SOGIESC group
* 		-> EQOSOGI 2024 Country Rankings, Overall and by SOGIESC Group
* 		-> EQOSOGI 2024 Country Rankings, Overall and by Indicator Set
* 		-> Boxplot: EQOSOGI 2024 Scores, by SOGIESC Group and Indicator Set
* 		-> EQOSOGI 2024 Scores, Sensitivity Analysis
* 2. Please run the first 64 lines of code before running the rest of the code
* 3. All inputs are separated and clearly identified from each other

clear all
set more off

* directory macros
global output_ "$eqosogi_userpath\Reproducibility package\outputs"

cd "$output_"

* Loading the EQOSOGI final database
use "EQOSOGI_final_database.dta", clear

order country countrycode region_dec region incomegroup_fy24 fcs_fy24 lending_cat pop_size legal_trad level_inclusive data_collect lgb_q1_1a t_q1_1b i_q1_1c lgb_q1_2 lgb_q1_3 lgb_q1_4a t_q1_4b i_q1_4c t_q1_5 i_q1_5 t_q1_6 lgb_q2_1a t_q2_1b i_q2_1c lgb_q2_2a t_q2_2b i_q2_2c lgb_q2_3a t_q2_3b i_q2_3c lgb_q2_4 t_q2_4 i_q2_4 lgb_q2_5 t_q2_5 i_q2_5 lgb_q2_6 t_q2_6 i_q2_6 lgb_q2_7 t_q2_7 i_q2_7 t_q2_8 lgb_q3_1_1a t_q3_1_1b i_q3_1_1c lgb_q3_1_2a t_q3_1_2b i_q3_1_2c lgb_q3_2_1a t_q3_2_1b i_q3_2_1c lgb_q3_2_2a t_q3_2_2b i_q3_2_2c lgb_q3_3a t_q3_3b i_q3_3c lgb_q3_4a t_q3_4b i_q3_4c lgb_q3_5a t_q3_5b i_q3_5c lgb_q3_6_1a t_q3_6_1b i_q3_6_1c lgb_q3_6_2a t_q3_6_2b i_q3_6_2c lgb_q3_7a t_q3_7b i_q3_7c lgb_q3_8_1 lgb_q3_8_2 t_q3_9 i_q3_9 t_q3_10 lgb_q4_1_1a t_q4_1_1b i_q4_1_1c lgb_q4_1_2a t_q4_1_2b i_q4_1_2c lgb_q4_1_3a t_q4_1_3b i_q4_1_3c lgb_q4_2 lgb_q4_3a t_q4_3b i_q4_3c lgb_q4_4a t_q4_4b i_q4_4c lgb_q4_5a t_q4_5b i_q4_5c lgb_q4_6a t_q4_6b i_q4_6c lgb_q4_7a t_q4_7b i_q4_7c lgb_q4_8a t_q4_8b i_q4_8c lgb_q4_9a t_q4_9b i_q4_9c i_q4_10a i_q4_10b i_q4_11 t_q4_12 i_q4_12 t_q4_13 lgb_q4_14 t_q4_14 i_q4_14 lgb_q5_1 t_q5_1 i_q5_1 lgb_q5_2 t_q5_2 i_q5_2 lgb_q5_3 t_q5_3 i_q5_3 lgb_q5_4a t_q5_4b i_q5_4c lgb_q5_5a t_q5_5b i_q5_5c lgb_q5_6 lgb_q5_7 lgb_q5_8 lgb_q5_9 lgb_q5_10 lgb_q5_11 lgb_q5_12 i_q5_13 lgb_q5_14 t_q5_14 lgb_q5_15a t_q5_15b i_q5_15c lgb_q5_16a t_q5_16b i_q5_16c lgb_q6_1_1a t_q6_1_1b i_q6_1_1c lgb_q6_2_2a t_q6_2_2b i_q6_2_2c lgb_q6_3_3a t_q6_3_3b i_q6_3_3c lgb_q6_4_4a t_q6_4_4b i_q6_4_4c lgb_q6_5_1 t_q6_5_1 i_q6_5_1 lgb_q6_5_2 t_q6_5_2 i_q6_5_2 lgb_q6_5_3 t_q6_5_3 i_q6_5_3 lgb_q6_5_4 t_q6_5_4 i_q6_5_4 lgb_q6_6_1 t_q6_6_1 i_q6_6_1 lgb_q6_6_2 t_q6_6_2 i_q6_6_2 lgb_q6_6_3 t_q6_6_3 i_q6_6_3 dim_1_lgb dim_2_lgb dim_3_lgb dim_4_lgb dim_5_lgb dim_6_lgb dim_1_t dim_2_t dim_3_t dim_4_t dim_5_t dim_6_t dim_1_i dim_2_i dim_3_i dim_4_i dim_5_i dim_6_i eqosogi_dim1 eqosogi_dim2 eqosogi_dim3 eqosogi_dim4 eqosogi_dim5 eqosogi_dim6 eqosogi_lgb_om eqosogi_t_om eqosogi_i_om eqosogi_score_om eqosogi_lgb_dm eqosogi_t_dm eqosogi_i_dm eqosogi_score_dm

* Attaching external data
preserve
use "EQOSOGI_database_data_analysis.dta", clear
keep countrycode wbl_* per_wbl_*
save "temp.dta", replace
restore

merge 1:1 countrycode using "temp.dta"
erase "temp.dta"
format countrycode %5s
keep if _merge==3
drop _merge

* Attaching data on external variables
preserve
use "external1.dta", clear
drop countryname
save "temp.dta"
restore

merge 1:1 countrycode using "temp.dta"
erase "temp.dta"
format countrycode %5s
keep if _merge==3
drop _merge

erase "EQOSOGI_database_data_analysis.dta"
erase "external1.dta"

* ------------------------------------- *
* Outcome 1: Figures 1.1 and Figure 1.2 *
* ------------------------------------- *

* Note: See the 'Figures_1.1_1.2' sheet in the 'EQOSOGI_ch1_outputs.xlsx' file

global dimensions "eqosogi_dim1 eqosogi_dim2 eqosogi_dim3 eqosogi_dim4 eqosogi_dim5 eqosogi_dim6"
global groups "eqosogi_lgb_dm eqosogi_t_dm eqosogi_i_dm"

* generating statistics by dimensions
qui: tabstat eqosogi_score_dm $dimensions, stats(mean min max) save
matlist r(StatTotal)' // export to excel
qui: tabstat eqosogi_score_dm $dimensions, stats(mean min p25 p50 p75 max) save
matlist r(StatTotal)' // export to excel

* generating statistics by groups
qui: tabstat eqosogi_score_dm $groups, stats(mean min max) save
matlist r(StatTotal)' // export to excel
qui: tabstat eqosogi_score_dm $groups, stats(mean min p25 p50 p75 max) save
matlist r(StatTotal)'

* ---------------------------------- *
* Outcome 2: Table 1.2 and Table 1.3 *
* ---------------------------------- *

* See the 'Table_1.2' and 'Table_1.3' sheets in the 'EQOSOGI_ch1_outputs.xlsx' file

sort country
order country eqosogi_score_dm $dimensions $groups
br country eqosogi_score_dm $dimensions // run and paste in excel
br country eqosogi_score_dm $groups // run and paste in excel

/*
* --------------------- *
* Outcome 3: Figure 1.3 *
* --------------------- *

qui: tabstat $groups eqosogi_score_dm, by(region) save
matrix define output = r(Stat1) \ r(Stat2) \ r(Stat3) \ r(Stat4) \ r(Stat5) \ r(Stat6) \ r(Stat7)
matlist output
*/

* ----------------------------------- *
* Outcome 3: Figure 1.3 (alternative) *
* ----------------------------------- *

* See the 'Figure_1.3_alternative' sheet in the 'EQOSOGI_ch1_outputs.xlsx' file

qui: tabstat $groups eqosogi_score_dm, by(region_dec) save
matrix define output = r(Stat1) \ r(Stat2) \ r(Stat3) \ r(Stat4) \ r(Stat5) \ r(Stat6) \ r(Stat7)
matlist output

/*
* --------------------- *
* Outcome 4: Figure 1.4 *
* --------------------- *

qui: tabstat $dimensions, by(region) save
matrix define output = r(Stat1) \ r(Stat2) \ r(Stat3) \ r(Stat4) \ r(Stat5) \ r(Stat6) \ r(Stat7)
matlist output'
*/

* ----------------------------------- *
* Outcome 4: Figure 1.4 (alternative) *
* ----------------------------------- *

* See the 'Figure_1.4_alternative' sheet in the 'EQOSOGI_ch1_outputs.xlsx' file

qui: tabstat $dimensions eqosogi_score_dm, by(region_dec) save
matrix define output = r(Stat1) \ r(Stat2) \ r(Stat3) \ r(Stat4) \ r(Stat5) \ r(Stat6) \ r(Stat7)
matlist output'

* --------------------- *
* Outcome 4: Figure 1.5 *
* --------------------- *

* See the 'Figure_1.5' sheet in the 'EQOSOGI_ch1_outputs.xlsx' file

qui: tabstat $dimensions eqosogi_score_dm, by(income) save
matrix define output = r(Stat1) \ r(Stat2) \ r(Stat3) \ r(Stat4)
matlist output' // please note the order of income groups in Stata is not the same as in the report (in Stata the order is alphabetically)

* -------------------- *
* Outcome 5: Table 3.1 *
* -------------------- *

/*
Covariates: 
	1) Per capita real GDP: real_pc_gdp (in logs)
	2) Gini Index: gini 
	3) Human Capital Index: hci 
	4) Voice and Accountability Estimate: voi_acc
*/

** Overall correlations
global controls "real_pc_gdp gini hci voi_acc"
local n_count = 0 // count of elements
foreach x in $controls{
	local n_count = `n_count' + 1
}

* overall score
local i = 0
foreach x in $controls{
	local i = `i' + 1
	pwcorr `x' eqosogi_score_dm, sig
	matrix define X = r(C)
	matrix define corr_`i' = X[2,1]
	matrix define X = r(sig)
	matrix define sig_`i' = X[2,1]
}
foreach k in corr sig{
	matrix define `k'_total = `k'_1
	forvalues t = 2/`n_count'{
		matrix define `k'_total = `k'_total \ `k'_`t'
	}
}

* indicator sets scores
forvalues t = 1/6{
	local i = 0
	foreach x in $controls{
		local i = `i' + 1
		if (`i'==2 & `t'==6){
			pwcorr `x' eqosogi_dim`t', sig
			matrix define X = r(C)
			matrix define corr_`i' = X[2,1]
			gen id = _n
			pwcorr `x' eqosogi_dim`t' if id<=10, sig
			matrix define X = r(sig)
			matrix define sig_`i' = X[2,1]
			drop id
		}
		else{
			pwcorr `x' eqosogi_dim`t', sig
			matrix define X = r(C)
			matrix define corr_`i' = X[2,1]
			matrix define X = r(sig)
			matrix define sig_`i' = X[2,1]
		}
	}
	foreach k in corr sig{
		matrix define `k'_dim`t' = `k'_1
		forvalues p = 2/`n_count'{
			matrix define `k'_dim`t' = `k'_dim`t' \ `k'_`p'
		}
	}
}

matrix define overall_corr = corr_total , corr_dim1 , corr_dim2 , corr_dim3 , corr_dim4 , corr_dim5 , corr_dim6
matrix define overall_sig = sig_total , sig_dim1 , sig_dim2 , sig_dim3 , sig_dim4 , sig_dim5 , sig_dim6

** Group correlations
foreach q in lgb t i{
	* group score
	local i = 0
	foreach x in $controls{
		local i = `i' + 1
		qui: pwcorr `x' eqosogi_`q'_dm, sig
		matrix define X = r(C)
		matrix define corr_`i' = X[2,1]
		matrix define X = r(sig)
		matrix define sig_`i' = X[2,1]
	}
	foreach k in corr sig{
		matrix define `k'_total = `k'_1
		forvalues t = 2/`n_count'{
			matrix define `k'_total = `k'_total \ `k'_`t'
		}
	}

	* indicator set group score
	forvalues t = 1/6{
		local i = 0
		foreach x in $controls{
			local i = `i' + 1
			if ("`q'"=="lgb" & `i'==2 & `t'==6){
				qui: pwcorr `x' dim_`t'_`q', sig
				matrix define X = r(C)
				matrix define corr_`i' = X[2,1]
				gen id = _n
				qui: pwcorr `x' dim_`t'_`q' if id<=10, sig
				matrix define X = r(sig)
				matrix define sig_`i' = X[2,1]
				drop id
			}
			else{
				qui: pwcorr `x' dim_`t'_`q', sig
				matrix define X = r(C)
				matrix define corr_`i' = X[2,1]
				matrix define X = r(sig)
				matrix define sig_`i' = X[2,1]
			}
		}
		foreach k in corr sig{
			matrix define `k'_dim`t' = `k'_1
			forvalues p = 2/`n_count'{
				matrix define `k'_dim`t' = `k'_dim`t' \ `k'_`p'
			}
		}
	}

	matrix `q'_corr = corr_total , corr_dim1 , corr_dim2 , corr_dim3 , corr_dim4 , corr_dim5 , corr_dim6
	matrix `q'_sig = sig_total , sig_dim1 , sig_dim2 , sig_dim3 , sig_dim4 , sig_dim5 , sig_dim6
}

** Final correlation matrices

* Note: See the 'Table_3.1' sheet in the 'EQOSOGI_ch3_outputs.xlsx' file

* Overall results
matlist overall_corr
matlist overall_sig
* Results for LGB group
matlist lgb_corr
matlist lgb_sig
* Results for T group
matlist t_corr
matlist t_sig
* Results for I group
matlist i_corr
matlist i_sig

* ---------------------------------------------------- *
* Outcome 6. Online appendix: Table 2. EQOSOGI dataset *
* ---------------------------------------------------- *

* See the 'Table 2. EQOSOGI dataset' sheet in the 'EQOSOGI_online_appendix_results.xlsx' file
order country* region* income* fcs* lending* pop_size legal_* data_collect all_* lgb_* t_* dim_* eqosogi_*
br country* region* income* fcs* lending* pop_size legal_* data_collect all_* lgb_* t_* dim_* eqosogi_*


* ------------------------------------------------------------------------------------ *
* Outcome 7. Online appendix: Table 3. Descriptive Statistics for All Binary Responses *
* ------------------------------------------------------------------------------------ *

* descriptive stats by indicator
global d1 "lgb_q1_1a t_q1_1b i_q1_1c lgb_q1_2 lgb_q1_3 lgb_q1_4a t_q1_4b i_q1_4c t_q1_5 t_q1_6"
global d2 "lgb_q2_1a t_q2_1b i_q2_1c lgb_q2_2a t_q2_2b i_q2_2c lgb_q2_3a t_q2_3b i_q2_3c lgb_q2_4 lgb_q2_5 lgb_q2_6 lgb_q2_7 t_q2_8"
global d3 "lgb_q3_1_1a t_q3_1_1b i_q3_1_1c lgb_q3_1_2a t_q3_1_2b i_q3_1_2c lgb_q3_2_1a t_q3_2_1b i_q3_2_1c lgb_q3_2_2a t_q3_2_2b i_q3_2_2c lgb_q3_3a t_q3_3b i_q3_3c lgb_q3_4a t_q3_4b i_q3_4c lgb_q3_5a t_q3_5b i_q3_5c lgb_q3_6_1a t_q3_6_1b i_q3_6_1c lgb_q3_6_2a t_q3_6_2b i_q3_6_2c lgb_q3_7a t_q3_7b i_q3_7c lgb_q3_8_1 lgb_q3_8_2 t_q3_9 t_q3_10"
global d4 "lgb_q4_1_1a t_q4_1_1b i_q4_1_1c lgb_q4_1_2a t_q4_1_2b i_q4_1_2c lgb_q4_1_3a t_q4_1_3b i_q4_1_3c lgb_q4_2 lgb_q4_3a t_q4_3b i_q4_3c lgb_q4_4a t_q4_4b i_q4_4c lgb_q4_5a t_q4_5b i_q4_5c lgb_q4_6a t_q4_6b i_q4_6c lgb_q4_7a t_q4_7b i_q4_7c lgb_q4_8a t_q4_8b i_q4_8c lgb_q4_9a t_q4_9b i_q4_9c i_q4_10a i_q4_10b i_q4_11 t_q4_12 t_q4_13 lgb_q4_14"
global d5 "lgb_q5_1 lgb_q5_2 lgb_q5_3 lgb_q5_4a t_q5_4b i_q5_4c lgb_q5_5a t_q5_5b i_q5_5c lgb_q5_6 lgb_q5_7 lgb_q5_8 lgb_q5_9 lgb_q5_10 lgb_q5_11 lgb_q5_12 i_q5_13 lgb_q5_14 lgb_q5_15a t_q5_15b i_q5_15c lgb_q5_16a t_q5_16b i_q5_16c"
global d6 "lgb_q6_1_1a t_q6_1_1b i_q6_1_1c lgb_q6_2_2a t_q6_2_2b i_q6_2_2c lgb_q6_3_3a t_q6_3_3b i_q6_3_3c lgb_q6_4_4a t_q6_4_4b i_q6_4_4c lgb_q6_5_1 lgb_q6_5_2 lgb_q6_5_3 lgb_q6_5_4 lgb_q6_6_1 lgb_q6_6_2 lgb_q6_6_3"

forvalues t = 1/6{
	qui: tabstat ${d`t'}, stats(mean p50 min max sd cv) save
	matrix define X`t' = r(StatTotal)
	matrix define X`t' = X`t''
}

* See the 'Table 3. descr_stat_binary' sheet in the 'EQOSOGI_online_appendix_results.xlsx' file

* Results for Decriminalization
matlist X1
* Results for Access to Education
matlist X2
* Results for Access to Labor Markets
matlist X3
* Results for Access to Services and Social Protection
matlist X4
* Results for Civil and Political Inclusion
matlist X5
* Results for Protection from Hate Crimes
matlist X6

* ---------------------------------------------------------------------------------------------------------- *
* Outcome 8. Online appendix: Table 4. Overall and indicator-set scores summary statistics, by SOGIESC group *
* ---------------------------------------------------------------------------------------------------------- *

* See the 'Table 5. summary_statistics' sheet in the 'EQOSOGI_online_appendix_results.xlsx' file

* Overall scores by SOGIESC groups + all groups
qui: tabstat eqosogi_lgb_dm eqosogi_t_dm eqosogi_i_dm eqosogi_score_dm, stats(mean min p25 p50 p75 max sd cv) save
matlist r(StatTotal)'
* Indicator-set scores for all groups
qui: tabstat eqosogi_dim1 eqosogi_dim2 eqosogi_dim3 eqosogi_dim4 eqosogi_dim5 eqosogi_dim6, stats(mean min p25 p50 p75 max sd cv) save
matlist r(StatTotal)'
* Indicator-set scores for LGB group
qui: tabstat dim_1_lgb dim_2_lgb dim_3_lgb dim_4_lgb dim_5_lgb dim_6_lgb, stats(mean min p25 p50 p75 max sd cv) save
matlist r(StatTotal)'
* Indicator-set scores for T group
qui: tabstat dim_1_t dim_2_t dim_3_t dim_4_t dim_5_t dim_6_t, stats(mean min p25 p50 p75 max sd cv) save
matlist r(StatTotal)'
* Indicator-set scores for I group
qui: tabstat dim_1_i dim_2_i dim_3_i dim_4_i dim_5_i dim_6_i, stats(mean min p25 p50 p75 max sd cv) save
matlist r(StatTotal)'

* ------------------------------------------------------------------------------------------------------ *
* Outcome 9. Online appendix: Figure 1. Boxplot: EQOSOGI 2024 Scores, by SOGIESC Group and Indicator Set *
* ------------------------------------------------------------------------------------------------------ *

* See the 'boxplots' sheet in the 'EQOSOGI_online_appendix_results.xlsx' file

br country eqosogi_*_dm eqosogi_score_dm eqosogi_dim*

* ---------------------------------------------------------------------- *
* Outcome 12. Online appendix: EQOSOGI 2024 Scores, Sensitivity Analysis *
* ---------------------------------------------------------------------- *

* See the 'sensitivity' in the 'EQOSOGI_online_appendix_results.xlsx' file

br country eqosogi_score_om eqosogi_score_dm
spearman eqosogi_score_om eqosogi_score_dm, star(0.01)
