* ============================================================== *
* Equality of Opportunity for Sexual and Gender Minorities 2024
* Code written by Omar Alburqueque, and reviewed by Paola Ballon
* Contact: oalburquequechav@worldbank.org
* < 2. EQOSOGI: External indicators >
* ============================================================== *

clear all
set more off

global input_ "$eqosogi_userpath\Reproducibility package\inputs"
global output_ "$eqosogi_userpath\Reproducibility package\outputs"

cd "$input_"

/*
Source: World Development Indicators (WDI)
Indicator list:
	- GDP (constant 2015 US$): ny.gdp.mktp.kd
	- GDP per capita (constant 2015 US$): ny.gdp.pcap.kd
	- GDP, PPP (constant 2017 international $): ny.gdp.mktp.pp.kd
	- GDP per capita, PPP (constant 2017 international $): ny.gdp.pcap.pp.kd
	- GDP growth (annual %): ny.gdp.mktp.kd.zg
	- GDP per capita growth (annual %): ny.gdp.pcap.kd.zg
	- Human Capital Index (HCI)(scale 0-1): hd.hci.ovrl
	- Labor force participation rate, total (% of total population ages 15+)(modeled ILO estimates): sl.tlf.cact.zs
	- Labor force participation rate, total (% of total population ages 15+)(national estimate): sl.tlf.cact.ne.zs
	- GDP per person employed (constant 2017 PPP $): sl.gdp.pcap.em.kd
	- Patent applications, residents: ip.pat.resd
	- Patent applications, nonresidents: ip.pat.nres
	- Trade (% of GDP): ne.trd.gnfs.zs
	- Gross capital formation (% of GDP): ne.gdi.totl.zs
	- Population ages 0-14, total: sp.pop.0014.to
	- Population ages 15-64, total: sp.pop.1564.to
	- Population ages 65 and above, total: sp.pop.65up.to
	- Research and development expenditure (% of GDP): gb.xpd.rsdv.gd.zs
	- Gini coefficient: si.pov.gini

Source: World Governance Indicators (WGI)
	- Control of Corruption: Estimate: cc.est
	- Government Effectiveness: Estimate: ge.est
	- Political Stability and Absence of Violence/Terrorism: Estimate: pv.est
	- Regulatory Quality: Estimate: rq.est
	- Rule of Law: Estimate: rl.est
	- Voice and Accountability: Estimate: va.est
	
Source: Doing Business
	- Ease of doing business score (DB17-20 methodology): ic.bus.ease.dfrn.xq.db1719
*/

** Source: World Development Indicators
local code_v1 = "ny.gdp.mktp.kd"
local vn_v1 = "real_gdp"
local lab_v1 = "GDP (constant 2015 US$)"
local code_v2 = "ny.gdp.pcap.kd"
local vn_v2 = "real_pc_gdp"
local lab_v2 = "GDP per capita (constant 2015 US$)"
local code_v3 = "ny.gdp.mktp.pp.kd"
local vn_v3 = "real_gdp_ppp"
local lab_v3 = "GDP, PPP (constant 2017 international $)"
local code_v4 = "ny.gdp.pcap.pp.kd"
local vn_v4 = "real_pc_gdp_ppp"
local lab_v4 = "GDP per capita, PPP (constant 2017 international $)"
local code_v5 = "ny.gdp.mktp.kd.zg"
local vn_v5 = "gdp_growth"
local lab_v5 = "GDP growth (annual %)"
local code_v6 = "ny.gdp.pcap.kd.zg"
local vn_v6 = "gdp_pc_growth"
local lab_v6 = "GDP per capita growth (annual %)"
local code_v7 = "hd.hci.ovrl"
local vn_v7 = "hci"
local lab_v7 = "Human Capital Index (HCI)(scale 0-1)"
local code_v8 = "sl.tlf.cact.zs"
local vn_v8 = "lfp_ilo"
local lab_v8 = "Labor force participation rate, total (% of total population ages 15+)(modeled ILO estimates)"
local code_v9 = "sl.tlf.cact.ne.zs"
local vn_v9 = "lfp_nat"
local lab_v9 = "Labor force participation rate, total (% of total population ages 15+)(national estimate)"
local code_v10 = "sl.gdp.pcap.em.kd"
local vn_v10 = "gdp_pemp"
local lab_v10 = "GDP per person employed (constant 2017 PPP $)"
local code_v11 = "ip.pat.resd"
local vn_v11 = "patent_res"
local lab_v11 = "Patent applications, residents"
local code_v12 = "ip.pat.nres"
local vn_v12 = "patent_nres"
local lab_v12 = "Patent applications, nonresidents"
local code_v13 = "ne.trd.gnfs.zs"
local vn_v13 = "trade_open"
local lab_v13 = "Trade (% of GDP)"
local code_v14 = "ne.gdi.totl.zs"
local vn_v14 = "capital_gdp"
local lab_v14 = "Gross capital formation (% of GDP)"
local code_v15 = "sp.pop.0014.to"
local vn_v15 = "pop_0_14"
local lab_v15 = "Population ages 0-14, total"
local code_v16 = "sp.pop.1564.to"
local vn_v16 = "pop_15_64"
local lab_v16 = "Population ages 15-64, total"
local code_v17 = "sp.pop.65up.to"
local vn_v17 = "pop_65_plus"
local lab_v17 = "Population ages 65+, total"
local code_v18 = "gb.xpd.rsdv.gd.zs"
local vn_v18 = "rd_gdp"
local lab_v18 = "Research and development expenditure (% of GDP)"
local code_v26 = "si.pov.gini"
local vn_v26 = "gini"
local lab_v26 = "Gini Index"

** Source: World Governance Indicators
local code_v19 = "cc.est"
local vn_v19 = "con_cor"
local lab_v19 = "Control of Corruption: Estimate"
local code_v20 = "ge.est"
local vn_v20 = "gov_eff"
local lab_v20 = "Government Effectiveness: Estimate"
local code_v21 = "pv.est"
local vn_v21 = "pol_sta"
local lab_v21 = "Political Stability and Absence of Violence/Terrorism: Estimate"
local code_v22 = "rq.est"
local vn_v22 = "reg_qua"
local lab_v22 = "Regulatory Quality: Estimate"
local code_v23 = "rl.est"
local vn_v23 = "rule_law"
local lab_v23 = "Rule of Law: Estimate"
local code_v24 = "va.est"
local vn_v24 = "voi_acc"
local lab_v24 = "Voice and Accountability: Estimate"

** Source: Doing Business
local code_v25 = "ic.bus.ease.dfrn.xq.db1719"
local vn_v25 = "doing_business"
local lab_v25 = "Ease of doing business score (DB17-20 methodology)"

** Extracting data
forvalues t = 1/26{
	qui: wbopendata, indicator(`code_v`t'') year(2005:2023) clear
	keep countrycode countryname region regionname yr*
	drop if region=="NA" | region=="" | regionname=="Aggregates"
	forvalues k = 2005/2023{
		capture: tab yr`k', rc
		if _rc==111{
			gen yr`k' = .
		}
	}
	gen v`t' = .
	replace v`t' = yr2023 if yr2023!=.
	replace v`t' = yr2022 if yr2023==. & yr2022!=.
	replace v`t' = yr2021 if yr2023==. & yr2022==. & yr2021!=.
	replace v`t' = yr2020 if yr2023==. & yr2022==. & yr2021==. & yr2020!=.
	replace v`t' = yr2019 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019!=.
	replace v`t' = yr2018 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018!=.
	replace v`t' = yr2017 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017!=.
	replace v`t' = yr2016 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016!=.
	replace v`t' = yr2015 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015!=.
	replace v`t' = yr2014 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014!=.
	replace v`t' = yr2013 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013!=.
	replace v`t' = yr2012 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012!=.
	replace v`t' = yr2011 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011!=.
	replace v`t' = yr2010 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010!=.
	replace v`t' = yr2009 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009!=.
	replace v`t' = yr2008 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008!=.
	replace v`t' = yr2007 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007!=.
	replace v`t' = yr2006 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007==. & yr2006!=.
	replace v`t' = yr2005 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007==. & yr2006==. & yr2005!=.
	
	gen per_v`t' = .
	replace per_v`t' = 2023 if yr2023!=.
	replace per_v`t' = 2022 if yr2023==. & yr2022!=.
	replace per_v`t' = 2021 if yr2023==. & yr2022==. & yr2021!=.
	replace per_v`t' = 2020 if yr2023==. & yr2022==. & yr2021==. & yr2020!=.
	replace per_v`t' = 2019 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019!=.
	replace per_v`t' = 2018 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018!=.
	replace per_v`t' = 2017 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017!=.
	replace per_v`t' = 2016 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016!=.
	replace per_v`t' = 2015 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015!=.
	replace per_v`t' = 2014 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014!=.
	replace per_v`t' = 2013 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013!=.
	replace per_v`t' = 2012 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012!=.
	replace per_v`t' = 2011 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011!=.
	replace per_v`t' = 2010 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010!=.
	replace per_v`t' = 2009 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009!=.
	replace per_v`t' = 2008 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008!=.
	replace per_v`t' = 2007 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007!=.
	replace per_v`t' = 2006 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007==. & yr2006!=.
	replace per_v`t' = 2005 if yr2023==. & yr2022==. & yr2021==. & yr2020==. & yr2019==. & yr2018==. & yr2017==. & yr2016==. & yr2015==. & yr2014==. & yr2013==. & yr2012==. & yr2011==. & yr2010==. & yr2009==. & yr2008==. & yr2007==. & yr2006==. & yr2005!=.
	
	rename v`t' `vn_v`t''
	rename per_v`t' per_`vn_v`t''
	
	keep countryname countrycode `vn_v`t'' per_`vn_v`t''
	
	* Labelling
	label var `vn_v`t'' "`lab_v`t''"
	label var per_`vn_v`t'' "Period: `lab_v`t''"
	
	save "temp_`t'.dta", replace
}

** Merge process
forvalues t = 1/26{
	if (`t'==1){
		use "temp_`t'.dta", clear
	}
	else{
		merge 1:1 countrycode using "temp_`t'.dta", nogenerate
	}
	erase "temp_`t'.dta"
}

/*
Changes in data for some covariates to resemble our data as in December 2023
	* Per capita real GDP
	* Gini Index
*/

local gdp_DZA = 3999.758
local gdp_ARG = 12940.74
local gdp_ARM = 5116.206
local gdp_BGD = 1784.739
local gdp_BTN = 2992.439
local gdp_BRA = 8831.128
local gdp_KHM = 1488.815
local gdp_CMR = 1441.795
local gdp_CAN = 44928.59
local gdp_CHL = 14355.61
local gdp_CHN = 11560.24
local gdp_CRI = 13424.46
local gdp_CIV = 2430.307
local gdp_DJI = 2950.947
local gdp_ECU = 5590.542
local gdp_EGY = 4088.897
local gdp_ETH = 857.3155
local gdp_FJI = 5313.028
local gdp_FRA = 38816.48
local gdp_GEO = 5438.604
local gdp_DEU = 43361.18
local gdp_GHA = 2031.428
local gdp_GNB = 621.8522
local gdp_GUY = 17646.22
local gdp_HTI = 1247.892
local gdp_HND = 2487.706
local gdp_IND = 2089.734
local gdp_IDN = 4073.611
local gdp_IRQ = 4335.783
local gdp_ISR = 42710.78
local gdp_JAM = 5236.79
local gdp_JPN = 36032.39
local gdp_JOR = 3891.212
local gdp_KEN = 1754.585
local gdp_KOR = 33719.39
local gdp_XKX = 4724.791
local gdp_KGZ = 1182.912
local gdp_LBN = 6107.455
local gdp_MUS = 10570.5
local gdp_MEX = 10077.38
local gdp_MNG = 4249.675
local gdp_MAR = 3300.8
local gdp_MOZ = 590.369
local gdp_NPL = 1083.035
local gdp_NZL = 42558.94
local gdp_NGA = 2449.588
local gdp_NOR = 79636.27
local gdp_PAK = 1695.957
local gdp_PNG = 2462.549
local gdp_PHL = 3527.981
local gdp_SRB = 7493.162
local gdp_ZAF = 6022.428
local gdp_ESP = 27702.75
local gdp_LKA = 3988.08
local gdp_SDN = 1684.63
local gdp_TZA = 1057.658
local gdp_THA = 6278.352
local gdp_TLS = 1611.469
local gdp_TUN = 3894.167
local gdp_TUR = 14055.11
local gdp_UKR = 2032.85
local gdp_URY = 18214.81
local gdp_VNM = 3655.463
local gdp_ZWE = 1345.769

foreach x in DZA ARG ARM BGD BTN BRA KHM CMR CAN CHL CHN CRI CIV DJI ECU EGY ETH FJI FRA GEO DEU GHA GNB GUY HTI HND IND IDN IRQ ISR JAM JPN JOR KEN KOR XKX KGZ LBN MUS MEX MNG MAR MOZ NPL NZL NGA NOR PAK PNG PHL SRB ZAF ESP LKA SDN TZA THA TLS TUN TUR UKR URY VNM ZWE{
	replace real_pc_gdp = `gdp_`x'' if countrycode=="`x'"
}

local gini_ARG = 42
local gini_BGD = 31.8
local gini_BRA = 52.9
local gini_CMR = 46.6
local gini_CHL = 44.9
local gini_CIV = 37.2
local gini_FRA = 30.7
local gini_GNB = 34.8
local gini_IND = 34.2
local gini_IDN = 37.9
local gini_ISR = 38.6
local gini_KGZ = 29
local gini_MEX = 45.4
local gini_MNG = 32.7
local gini_SRB = 35
local gini_ESP = 34.9
local gini_THA = 35.1
local gini_TUN = 32.8
local gini_TUR = 41.9
local gini_URY = 40.8
local gini_VNM = 36.8

foreach x in ARG BGD BRA CMR CHL CIV FRA GNB IND IDN ISR KGZ MEX MNG SRB ESP THA TUN TUR URY VNM{
	replace gini = `gini_`x'' if countrycode=="`x'"
}

replace gini = . if countrycode=="JAM"

save "external1.dta", replace

/*
Source: Women, Business, and the Law (WBL)
	- WBL: overall score
	- WBL: mobility score
	- WBL: workplace score
	- WBL: pay score
	- WBL: marriage score
	- WBL: parenthood score
	- WBL: entrepreneurship score
	- WBL: assets score
	- WBL: pension score
*/

use "WBL1971-2023.dta", clear
rename ISOcode countrycode
keep countrycode year WBL_index GR1_mobility GR2_workplace GR3_pay GR4_marriage GR5_parenthood GR6_entrprnshp GR7_assets GR8_pension
keep if year==2022
rename WBL_index wbl_score
rename GR1_mobility wbl_s_mobility
rename GR2_workplace wbl_s_workplace
rename GR3_pay wbl_s_pay
rename GR4_marriage wbl_s_marriage
rename GR5_parenthood wbl_s_parenthood
rename GR6_entrprnshp wbl_s_entrepreneurship
rename GR7_assets wbl_s_assets
rename GR8_pension wbl_s_pension
keep countrycode wbl*

local t_core = "WBL: overall score"
local t_mobility = "WBL: mobility score"
local t_workplace = "WBL: workplace score"
local t_pay = "WBL: pay score"
local t_marriage = "WBL: marriage score"
local t_parenthood = "WBL: parenthood score"
local t_entrepreneurship = "WBL: entrepreneurship score"
local t_assets = "WBL: assets score"
local t_pension = "WBL: pension score"

foreach x in core _mobility _workplace _pay _marriage _parenthood _entrepreneurship _assets _pension{
	label var wbl_s`x' "`t_`x''"
	gen per_wbl_s`x' = 2022
	label var per_wbl_s`x' "Period: `t_`x''"
}

save "external2.dta", replace

/*
Source: Allianz Country Risk Rating
	- Medium-term rating (country grade)
	- Short-term rating (country risk level)
*/

import excel using "country_risk_ratings_Allianz_2023.xlsx", firstrow clear
rename Country countryname
rename MediumTermRatingCountryGrad mrisk_rating
rename ShortTermRatingCountryRisk srisk_rating
gen t1 = .
replace t1 = 1 if mrisk_rating=="AA"
replace t1 = 2 if mrisk_rating=="A"
replace t1 = 3 if mrisk_rating=="BB"
replace t1 = 4 if mrisk_rating=="B"
replace t1 = 5 if mrisk_rating=="C"
replace t1 = 6 if mrisk_rating=="D"
label define mrisk 1 "AA" 2 "A" 3 "BB" 4 "B" 5 "C" 6 "D"
label values t1 mrisk
drop mrisk_rating
rename t1 mrisk_rating

gen t2 = substr(srisk_rating,1,1)
destring t2, replace
label define srisk 1 "Low" 2 "Medium" 3 "Sensitive" 4 "High"
label values t2 srisk
drop srisk_rating
rename t2 srisk_rating

label var mrisk_rating "Medium-term rating (country grade)"
label var srisk_rating "Short-term rating (country risk level)"

* Rename countries
replace countryname = "Antigua and Barbuda" if countryname=="Antigua & Barbuda"
replace countryname = "Bahamas, The" if countryname=="Bahamas"
replace countryname = "Brunei Darussalam" if countryname=="Brunei"
replace countryname = "Cabo Verde" if countryname=="Cape Verde Islands"
replace countryname = "Congo, Dem Rep" if countryname=="Congo (Democratic Rep Of)"
replace countryname = "Congo, Rep" if countryname=="Congo (People's Rep Of)"
replace countryname = "Cote d'Ivoire" if countryname=="Côte d'Ivoire"
replace countryname = "Egypt, Arab Rep" if countryname=="Egypt"
replace countryname = "Gambia, The" if countryname=="Gambia"
replace countryname = "Guinea" if countryname=="Guinea (Rep Of)"
replace countryname = "Guinea-Bissau" if countryname=="Guinea Bissau"
replace countryname = "Hong Kong SAR, China" if countryname=="Hong Kong"
replace countryname = "Iran, Islamic Rep" if countryname=="Iran"
replace countryname = "North Korea" if countryname=="North Korea"
replace countryname = "Korea, Rep" if countryname=="South Korea"
replace countryname = "Kyrgyz Republic" if countryname=="Kyrgyzstan"
replace countryname = "Lao PDR" if countryname=="Laos"
replace countryname = "Macao SAR, China" if countryname=="Macao"
replace countryname = "Micronesia, Fed Sts" if countryname=="Micronesia"
replace countryname = "Myanmar" if countryname=="Myanmar (Burma)"
replace countryname = "Russian Federation" if countryname=="Russia"
replace countryname = "Sao Tome and Principe" if countryname=="Sao Tome & Principe"
replace countryname = "Slovak Republic" if countryname=="Slovakia"
replace countryname = "St Lucia" if countryname=="St. Lucia"
replace countryname = "St Martin (French part)" if countryname=="St. Maarten"
replace countryname = "St Kitts and Nevis" if countryname=="St. Kitts & Nevis"
replace countryname = "St Vincent and the Grenadines" if countryname=="St. Vincent & The Grenadines"
replace countryname = "Syrian Arab Republic" if countryname=="Syria"
replace countryname = "Taiwan, China" if countryname=="Taiwan"
replace countryname = "Timor-Leste" if countryname=="Timor Leste"
replace countryname = "Trinidad and Tobago" if countryname=="Trinidad & Tobago"
replace countryname = "Turks and Caicos Islands" if countryname=="Turks & Caicos"
replace countryname = "Venezuela, RB" if countryname=="Venezuela"
replace countryname = "Virgin Islands (US)" if countryname=="US Virgin Islands"
replace countryname = "Yemen, Rep" if countryname=="Yemen"
save "external3.dta", replace

/*
Source: Social Sustainability Global Database (SSGD)
	- % of ppl that says they have confidence in the Police
	- % of ppl that says they have confidence in the Justice System
	- % of ppl that says they have confidence in the elections
	- % of ppl that says they have confidence in the government
	- % of ppl that says most people can be trusted
	- % of ppl that feels insecure living in their area/neighborhood
*/
use "ssgd_v_2_0.dta", clear
keep if group=="nat"
keep countrycode sc_trupeo_w2 per_sc_trupeo_w2 sc_conpol_w2 per_sc_conpol_w2 sc_conjus_w2 per_sc_conjus_w2 sc_conele_w2 per_sc_conele_w2 sc_congov_w2 per_sc_congov_w2 sc_insnei_w2 per_sc_insnei_w2

merge 1:1 countrycode using "external1.dta", nogenerate
merge 1:1 countrycode using "external2.dta", nogenerate

drop if countryname==""
replace countryname = "North Korea" if countrycode=="PRK"
merge 1:1 countryname using "external3.dta"
drop if _merge==2
drop _merge

preserve
use "external1.dta", clear
save "$output_\external1.dta", replace
restore

erase "external1.dta"
erase "external2.dta"
erase "external3.dta"

** Final attachment: EQOSOGI database
merge 1:1 countrycode using "$output_\EQOSOGI_final_database.dta"
keep if _merge==3
drop _merge

save "$output_\EQOSOGI_database_data_analysis.dta", replace
